@@ -125,8 +125,8 @@ ppl_prep_data <- function(data, Subject = NULL, Item = NA,
     # Conversion helper function
     .conversionhelper <- function(data, columnname, datamode){
       if(datamode=="numeric"){
-        if (is.numeric(data[, columnname]) == FALSE){
-          if(is.factor(data[, columnname]) == TRUE){
+        if (is.numeric(data[[columnname]]) == FALSE){
+          if(is.factor(data[[columnname]]) == TRUE){
             data[, columnname] <- lapply(data[, columnname], as.character)
           }
           conv <- lapply(data[, columnname], as.numeric)
@@ -137,7 +137,7 @@ ppl_prep_data <- function(data, Subject = NULL, Item = NA,
         }
       }
       if(datamode=="factor"){
-        if (is.factor(data[, columnname]) == FALSE){
+        if (is.factor(data[[columnname]]) == FALSE){
           conv <- lapply(data[, columnname], factor)
           message(paste0("    ", columnname, " converted to factor."))
         } else {
@@ -171,9 +171,9 @@ ppl_prep_data <- function(data, Subject = NULL, Item = NA,
       item <- enquo(item)
       data <- rename(data, Item = !!item)
       message(paste("   ", quo_name(item), "renamed to Item."))
-      reqcols <- rbind(reqcols, c("Item", "factor", 1))
+      reqcols <- rbind(reqcols, c("Item", 1, "factor"))
     } else {
-      reqcols <- rbind(reqcols, c("Item", "factor", 0))
+      reqcols <- rbind(reqcols, c("Item", 0, "factor"))
       message("    No Item column specified.")
     }
 
@@ -368,7 +368,7 @@ ppl_rm_extra_DVcols <- function(data, Keep=NULL){
 #' @import rlang
 #' @import VWPre
 #'
-#' @param data A data table object output by \code{\link{create_time_series}}.
+#' @param data A data table object output by \code{\link[VWPre]{create_time_series}}.
 #' @param Recording A string indicating which eyes were used for recording gaze data
 #' ("R" when only right eye recording is present, "L" when only left eye recording
 #' is present, "LorR" when either the left or the right eye was recorded, "LandR"
@@ -413,7 +413,6 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
           stop("Please specify which eye to use when Recording is set to 'LandR'!")
         }
         tmp <- data %>%
-          group_by(Event) %>%
           mutate(., EyeRecorded = as.character(EYE_TRACKED)) %>%
           do(
             mutate(., EyeSelected = ifelse(EyeRecorded %in% c("Both", "Binocular") & WhenLandR == "Right", "Right",
@@ -442,12 +441,13 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
                                                     sum(UQ(sym(eval_tidy(rcol))), na.rm = TRUE) == 0, "Left",
                                                   ifelse(sum(UQ(sym(eval_tidy(lcol))), na.rm = TRUE) == 0 &&
                                                            sum(UQ(sym(eval_tidy(rcol))), na.rm = TRUE) > 0, "Right", "NoData")))) %>%
+            ungroup() %>%
             do(
               mutate(., EyeSelected = ifelse(EyeRecorded == "Both" & WhenLandR == "Right", "Right",
                                              ifelse(EyeRecorded == "Both" & WhenLandR == "Left", "Left",
                                                     ifelse(EyeRecorded == "Right", EyeRecorded,
                                                            ifelse(EyeRecorded == "Left", EyeRecorded,
-                                                                  ifelse(EyeRecorded == "NoData", "Neither"))))))
+                                                                  ifelse(EyeRecorded == "NoData", "Neither", NA))))))
             )
 
 
@@ -462,10 +462,11 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
                                            ifelse(sum(UQ(sym(eval_tidy(lcol))), na.rm = TRUE) == 0 &
                                                     sum(UQ(sym(eval_tidy(rcol))), na.rm = TRUE) > 0,
                                                   "Right", "NoData"))) %>%
+            ungroup() %>%
             do(
               mutate(., EyeSelected = ifelse(EyeRecorded == "Right", EyeRecorded,
                                              ifelse(EyeRecorded == "Left", EyeRecorded,
-                                                    ifelse(EyeRecorded == "NoData", "Neither"))))
+                                                    ifelse(EyeRecorded == "NoData", "Neither", NA))))
             )
 
         }
@@ -484,9 +485,10 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
           tmp <- data %>%
             group_by(Event) %>%
             mutate(., EyeRecorded = ifelse(sum(UQ(sym(eval_tidy(col))), na.rm = TRUE) > 0, quo_name(val), "NoData")) %>%
+            ungroup() %>%
             do(
               mutate(., EyeSelected = ifelse(EyeRecorded == quo_name(val), EyeRecorded,
-                                             ifelse(EyeRecorded == "NoData", "Neither")))
+                                             ifelse(EyeRecorded == "NoData", "Neither", NA)))
             ) %>% ungroup()
         }
 
@@ -496,7 +498,7 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
     } ## SHARED CODE ENDS HERE ##
 
   # Transfer columns
-    tmp <- tmp %>% group_by(Event) %>%
+    tmp <- tmp %>%
         mutate(., Pupil = ifelse(EyeSelected == "Right", RIGHT_PUPIL_SIZE,
                                  ifelse(EyeSelected == "Left", LEFT_PUPIL_SIZE, NA)),
                Gaze_X = ifelse(EyeSelected == "Right", RIGHT_GAZE_X,
@@ -526,6 +528,7 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
     tmp$In_Blink <- as.numeric(as.character(tmp$In_Blink))
     tmp$In_Saccade <- as.numeric(as.character(tmp$In_Saccade))
     tmp <- tmp %>%
+      group_by(Event) %>%
       mutate(Pupil_Data = ifelse(sum(Pupil, na.rm = TRUE) > 0, "Contains_Pupil_Data", "No_Pupil_Data"))
     tmp$Pupil_Data <- as.factor(as.character(tmp$Pupil_Data))
 
@@ -535,7 +538,7 @@ ppl_select_recorded_eye <- function(data, Recording = NULL, WhenLandR = NA) {
   message(paste("Gaze data summary for", length(unique(levels(tmp$Event))), "events:"))
 
   if (!(is.na(WhenLandR))) {
-      n <- tmp %>% group_by(Event) %>% summarise(T1 = min(Time), Eye = EyeSelected[1]) %>% filter(Eye=="Both") %>% droplevels()
+      n <- tmp %>% group_by(Event) %>% summarise(T1 = min(Time), Eye = EyeRecorded[1]) %>% filter(Eye=="Both" | Eye == "Binocular") %>% droplevels()
     message(paste(nrow(n), "event(s) contained gaze data for both eyes, for which the", WhenLandR, "eye has been selected." ))
   }
 
@@ -600,7 +603,7 @@ recode_off_screen <- function(data = data, ScreenSize = NULL, PlotData = FALSE){
 
   # Mark data points
   message(paste0("Marking data points outside of ", ScreenSize[1], "x", ScreenSize[2], "."))
-  tmp <- data %>% group_by(Event) %>%
+  tmp <- data %>%
     do(
     mutate(., Screen = case_when(
       is.na(Gaze_X) | is.na(Gaze_Y) ~ "Unknown",
@@ -1480,6 +1483,7 @@ interpolate_NAs <- function(data = data, Method = "linear", XandY = TRUE, MinDat
 #' stop-band (band-reject) filter, or "pass" for a pass-band filter.
 #' @param plane A character string (as described in \link[signal]{butter}), "z"
 #' for a digital filter or "s" for an analog filter.
+#' @return An object of type data table as described in \link[tibble]{tibble}.
 #' @examples
 #' # Load example data
 #' data("Pupilex5")
@@ -1701,8 +1705,8 @@ baseline = function(data = data, BaselineWindow = 0, BaselineType = NULL, DiffBa
 #' @import rlang
 #'
 #' @param data A data frame object created from \code{blink_cleanup}.
-#' @param SamplingRate A postive integer specifying the current sampling rate.
-#' @param NewRate A postive integer specifying the desired downsampled rate.
+#' @param SamplingRate A positive integer specifying the current sampling rate.
+#' @param NewRate A positive integer specifying the desired downsampled rate.
 #' @return An object of type data table as described in \link[tibble]{tibble}.
 #' @examples
 #' # Load example data
